@@ -946,6 +946,15 @@ register_stock_icons (void)
 	g_object_unref (G_OBJECT (factory));
 }
 
+static gboolean
+start_playing (GnomeCD *gcd)
+{
+	/* Just fake a click on the button */
+	play_cb (NULL, gcd);
+
+	return FALSE; /* only call once */
+}
+
 int 
 main (int argc, char *argv[])
 {
@@ -957,7 +966,7 @@ main (int argc, char *argv[])
 		{ "play",   '\0', 0, G_OPTION_ARG_NONE, &cd_option_play,
 		  N_("Play the CD on startup"), NULL },
 		{ "tray", '\0', 0, G_OPTION_ARG_NONE, &cd_option_tray,
-		  N_("Start iconified to tray"), NULL},
+		  N_("Start iconified in notification area"), NULL},
 		{ NULL, '\0', 0, 0, NULL, NULL, NULL }
 	};
 
@@ -968,6 +977,8 @@ main (int argc, char *argv[])
 
 	free (malloc (8)); /* -lefence */
 
+	g_thread_init (NULL);
+
 	if (g_getenv ("GNOME_CD_DEBUG")) {
 		debug_mode = TRUE;
 	}
@@ -1008,8 +1019,11 @@ main (int argc, char *argv[])
 			  G_CALLBACK (client_die), gcd);
 
 	if (cd_option_play || gcd->preferences->start_play) {
-		/* Just fake a click on the button */
-		play_cb (NULL, gcd);
+		/* we do this delayed with a low priority to give the
+		 * GStreamer backend a chance to process any pending TAG
+		 * messages on the bus first (so it knows the CD layout) */
+		g_idle_add_full (G_PRIORITY_LOW, (GSourceFunc) start_playing,
+		                 gcd, NULL);
 	}
 	
 	if (cd_option_unique &&
