@@ -10,7 +10,7 @@
 #include <config.h>
 #endif
 
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n.h>
 #include <sys/types.h>
 #include <sys/ioctl.h>
 #include <fcntl.h>
@@ -209,13 +209,16 @@ linux_cdrom_update_cd (GnomeCDRom *cdrom)
 		g_warning ("Error getting leadout");
 		linux_cdrom_invalidate (lcd);
 		g_free (priv->track_info);
+		priv->track_info = NULL;
 		return;
 	}
 	ASSIGN_MSF (priv->track_info[priv->number_tracks].address, tocentry.cdte_addr.msf);
 	calculate_track_lengths (lcd);
 
 	linux_cdrom_close (lcd);
-	g_free (priv->track_info);
+	//g_free (priv->track_info);
+	//priv->track_info = NULL;
+
 	return;
 }
 
@@ -862,7 +865,7 @@ linux_cdrom_get_status (GnomeCDRom *cdrom,
 				g_print ("Error reading CD header");
 				linux_cdrom_close (lcd);
 
-				return;
+				return FALSE;
 			}
 			realstatus->cd = GNOME_CDROM_STATUS_DATA_CD;
 
