@@ -21,6 +21,8 @@
 
 #include <config.h>
 #include <gtk/gtkmain.h>
+#include <libgnome/gnome-program.h>
+#include <libgnomeui/gnome-ui-init.h>
 #include "gnome-media-profiles.h"
 #include "audio-profile-private.h"
 
@@ -35,9 +37,16 @@ int
 main (int argc, char *argv[])
 {
   GtkWidget *widget;
-  static GConfClient *conf;
+  GConfClient *conf;
+  GnomeProgram *program;
+
+  program = gnome_program_init ("gnome-audio-profiles-properties",
+			        VERSION,
+			        LIBGNOMEUI_MODULE,
+			        argc, argv,
+				GNOME_PARAM_APP_DATADIR, DATADIR,
+			        GNOME_PARAM_NONE);
 
-  gtk_init (&argc, &argv);
   /* FIXME: add a comment why we need this at all, until then
      we comment it out
   gm_audio_profile_edit_get_type (); */
@@ -49,6 +58,8 @@ main (int argc, char *argv[])
   textdomain (GETTEXT_PACKAGE);
   gnome_media_profiles_init (conf);
 
+  gtk_window_set_default_icon_name ("gnome-mime-audio");
+
   widget = GTK_WIDGET (gm_audio_profiles_edit_new (conf, NULL));
   g_assert (GTK_IS_WIDGET (widget));
 
@@ -58,5 +69,8 @@ main (int argc, char *argv[])
   gtk_widget_show_all (widget);
   gtk_main ();
 
+  g_object_unref (conf);
+  g_object_unref (program);
+
   return 0;
 }
